@@ -12,6 +12,9 @@ namespace NetworKit {
 AdjacencyMatrix::AdjacencyMatrix(const Graph &graph) : Matrix(graph.upperNodeIdBound()) {
 	graph.forEdges([&](const node &i, const node &j, double edgeWeight) {
 		setValue(i, j, edgeWeight);
+		if (!graph.isDirected()) {
+			setValue(j, i, edgeWeight);
+		}
 	});
 }
 
