@@ -9,11 +9,12 @@
 #define MAXCLIQUE_H_
 
 #include "../graph/Graph.h"
-#include <set>
+#include <unordered_set>
 
 
 namespace NetworKit {
 
+
 /**
  * Exact algorithm for computing the size of the largest clique in a graph.
  * Worst-case running time is exponential, but in practice the algorithm is fairly fast.
@@ -23,12 +24,13 @@ class MaxClique {
 protected:
 	const Graph& G;
 	count maxi;
+	std::unordered_set<node> bestClique;
 
 	/**
 	 * Subroutine that goes through every relevant clique containing a certain node in
 	 * a recursive fashion and computes the size of the largest.
 	 */
-	void clique(std::set<node>& U, count size);
+	void clique(std::unordered_set<node>& U, std::unordered_set<node>& currClique, count size);
 
 public:
 	/**
@@ -47,10 +49,15 @@ public:
 	void run();
 
 	/**
-	 * Get size of maximum clique
-	 * @return size of maximum clique
+	 * Get size of maximum clique.
+	 * @return Size of maximum clique
 	 */
 	count getMaxCliqueSize();
+
+	/**
+	 * @return Largest clique of the graph.
+	 */
+	std::unordered_set<node> getMaxClique() const;
 };
 
 } /* namespace NetworKit */
