@@ -1,5 +1,5 @@
 /*
- * Contracter.h
+ * GraphCoarsening.h
  *
  *  Created on: 30.10.2012
  *      Author: Christian Staudt (christian.staudt@kit.edu)
@@ -29,13 +29,21 @@ public:
 
 	Graph getCoarseGraph() const;
 
-	std::vector<node> getNodeMapping() const;
+	/**
+	 * Get mapping from fine to coarse node.
+	 */
+	std::vector<node> getFineToCoarseNodeMapping() const;
+
+	/**
+	 * Get mapping from coarse node to collection of fine nodes.
+	 */
+	std::map<node, std::vector<node> > getCoarseToFineNodeMapping() const;
 
 	virtual std::string toString() const;
 
 protected:
 	const Graph& G;
-	Graph Gcoarsed;
+	Graph Gcoarsened;
 	std::vector<node> nodeMapping;
 
 };
