@@ -228,7 +228,8 @@ private:
 	template<class F,
 			 typename std::enable_if<
 			 (Aux::FunctionTraits<F>::arity >= 2) &&
-			 std::is_same<edgeid, typename Aux::FunctionTraits<F>::template arg<2>::type>::value
+			 std::is_same<edgeid, typename Aux::FunctionTraits<F>::template arg<2>::type>::value &&
+			 std::is_same<node, typename Aux::FunctionTraits<F>::template arg<1>::type>::value /* prevent f(v, weight, eid) */
 			 >::type* = (void*)0>
 	auto edgeLambda(F&f, node u, node v, edgeweight ew, edgeid id) const -> decltype(f(u, v, id)) {
 		return f(u, v, id);
@@ -444,6 +445,7 @@ public:
 	 * Add a new node to the graph with coordinates @a x and @y and return it.
 	 */
 	// TODO: remove method
+	// [[deprecated("Deprecated: Node coordinates should be stored externally like any other node attribute")]]
 	node addNode(float x, float y);
 
 	/**
@@ -640,6 +642,24 @@ public:
 	*/
 	std::pair<count, count> const size() { return {n, m}; };
 
+
+	/**
+	 * @return the density of the graph
+	 */
+	double density() const {
+		count n = numberOfNodes();
+		count m = numberOfEdges();
+		count loops = numberOfSelfLoops();
+		m -= loops;
+		double d;
+		if (isDirected()) {
+			d = m / (double) (n * (n-1));
+		} else {
+			d = (2 * m) / (double) (n * (n-1));
+		}
+		return d;
+	}
+
 	/**
 	 * Return the number of loops {v,v} in the graph.
 	 * @return The number of loops.
@@ -686,6 +706,7 @@ public:
 	 * @param value The coordinate of @a v.
 	 */
 	// TODO: remove method
+	// [[deprecated("Deprecated: Node coordinates should be stored externally like any other node attribute")]]
 	void setCoordinate(node v, Point<float> value) { coordinates.setCoordinate(v, value); }
 
 
@@ -698,6 +719,7 @@ public:
 	 * @return The coordinate of @a v.
 	 */
 	// TODO: remove method
+	// [[deprecated("Deprecated: Node coordinates should be stored externally like any other node attribute")]]
 	Point<float>& getCoordinate(node v) { return coordinates.getCoordinate(v); }
 
 	/**
@@ -709,6 +731,7 @@ public:
 	 * @return The minimum coordinate in dimension @a dim.
 	 */
 	// TODO: remove method
+	// [[deprecated("Deprecated: Node coordinates should be stored externally like any other node attribute")]]
 	float minCoordinate(count dim) { return coordinates.minCoordinate(dim); }
 
 	/**
@@ -720,6 +743,7 @@ public:
 	 * @return The maximum coordinate in dimension @a dim.
 	 */
 	// TODO: remove method
+	// [[deprecated("Deprecated: Node coordinates should be stored externally like any other node attribute")]]
 	float maxCoordinate(count dim) { return coordinates.maxCoordinate(dim); }
 
 	/**
@@ -731,6 +755,7 @@ public:
 	 * been added.
 	 */
 	// TODO: remove method
+	// [[deprecated("Deprecated: Node coordinates should be stored externally like any other node attribute")]]
 	void initCoordinates() { coordinates.init(z); }
 
 
@@ -1052,33 +1077,33 @@ void Graph::parallelForNodePairs(L handle) const {
 template<bool hasWeights> // implementation for weighted == true
 inline edgeweight Graph::getOutEdgeWeight(node u, index i) const {
 	return outEdgeWeights[u][i];
-};
+}
 
 template<> // implementation for weighted == false
 inline edgeweight Graph::getOutEdgeWeight<false>(node, index) const {
 	return defaultEdgeWeight;
-};
+}
 
 template<bool hasWeights> // implementation for weighted == true
 inline edgeweight Graph::getInEdgeWeight(node u, index i) const {
 	return inEdgeWeights[u][i];
-};
+}
 
 template<> // implementation for weighted == false
 inline edgeweight Graph::getInEdgeWeight<false>(node, index) const {
 	return defaultEdgeWeight;
-};
+}
 
 
 template<bool graphHasEdgeIds> // implementation for hasEdgeIds == true
 inline edgeid Graph::getOutEdgeId(node u, index i) const {
 	return outEdgeIds[u][i];
-};
+}
 
 template<> // implementation for hasEdgeIds == false
 inline edgeid Graph::getOutEdgeId<false>(node, index) const {
 	return 0;
-};
+}
 
 template<bool graphHasEdgeIds> // implementation for hasEdgeIds == true
 inline edgeid Graph::getInEdgeId(node u, index i) const {
@@ -1420,7 +1445,7 @@ void Graph::BFSEdgesFrom(node r, L handle) const {
 		node u = q.front();
 		q.pop();
 		// apply function
-		forNeighborsOf(u, [&](node v, edgeweight w, edgeid eid) {
+		forNeighborsOf(u, [&](node, node v, edgeweight w, edgeid eid) {
 			if (!marked[v]) {
 				handle(u, v, w, eid);
 				q.push(v);
