@@ -57,11 +57,13 @@ public:
 	Point& scale(const T factor);
 
 	Point operator-(const Point<T>& other);
+	Point operator+(const Point<T>& other);
 
 	T length() const;
 	T squaredLength() const;
 
 	T& operator[](const index i);
+	T& at(const index i);
 
 	/**
 	 * Default point to string conversion.
@@ -147,6 +149,16 @@ Point<T> Point<T>::operator-(const Point<T>& other) {
 	return result;
 }
 
+template<class T>
+Point<T> Point<T>::operator+(const Point<T>& other) {
+	Point<T> result(*this);
+	assert(result.data.size() == other.data.size());
+	for (index i = 0; i < result.data.size(); ++i) {
+		result.data[i] += other.data[i];
+	}
+	return result;
+}
+
 
 template<class T>
 Point<T>& Point<T>::scale(const T factor) {
@@ -162,6 +174,12 @@ inline T& Point<T>::operator [](index i) {
 	return data[i];
 }
 
+template<class T>
+inline T& Point<T>::at(index i) {
+	assert(i >= 0 && i < data.size());
+	return data[i];
+}
+
 template<class T>
 std::ostream& operator <<(std::ostream& out, Point<T>& point)
 {
